==> istio-model-v1alpha3-5.11.0-sources.jar: annotations/io/fabric8/istio/api/networking/v1alpha3/WorkloadSelectorFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class WorkloadSelectorFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.WorkloadSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.WorkloadSelectorFluent<A>{
  public WorkloadSelectorFluentImpl() {
  }
  public WorkloadSelectorFluentImpl(io.fabric8.istio.api.networking.v1alpha3.WorkloadSelector instance) {
    this.withLabels(instance.getLabels()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> labels;
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WorkloadSelectorFluentImpl that = (WorkloadSelectorFluentImpl) o;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-5.12.3-sources.jar: annotations/io/fabric8/istio/api/networking/v1alpha3/WorkloadSelectorFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class WorkloadSelectorFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.WorkloadSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.WorkloadSelectorFluent<A>{
  public WorkloadSelectorFluentImpl() {
  }
  public WorkloadSelectorFluentImpl(io.fabric8.istio.api.networking.v1alpha3.WorkloadSelector instance) {
    this.withLabels(instance.getLabels()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> labels;
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WorkloadSelectorFluentImpl that = (WorkloadSelectorFluentImpl) o;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  super.hashCode());
  }
  
}
